#
# spec file for package libimagequant
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   0
%define libname %{name}%{sover}
Name:           libimagequant
Version:        2.18.0
Release:        1.4
Summary:        Palette quantization library
License:        GPL-3.0-or-later
Group:          Development/Languages/C and C++
URL:            https://pngquant.org/lib/
Source0:        https://github.com/ImageOptim/libimagequant/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(lcms2)

%description
C library for conversion of RGBA images to 8-bit indexed-color
(palette) images.

%package -n %{libname}
Summary:        Palette quantization library
Group:          System/Libraries

%description -n %{libname}
C library for conversion of RGBA images to 8-bit indexed-color
(palette) images.

%package devel
Summary:        Development files for libimagequant
Group:          Development/Languages/C and C++
Requires:       %{libname} = %{version}

%description devel
C library for conversion of RGBA images to 8-bit indexed-color
(palette) images.

%prep
%setup -q

%build
# This is not an autoconf configure, but the script simply ignores parameters it does not know
%configure \
%ifnarch %ix86 x86_64
    --disable-sse \
%endif
    --with-openmp
make %{?_smp_mflags}

%install
%make_install

# work around --disable-static not working
find %{buildroot} \( -name '*.a' -o -name '*.la' \) -print -delete

%post   -n libimagequant0 -p /sbin/ldconfig
%postun -n libimagequant0 -p /sbin/ldconfig

%files -n libimagequant0
%doc README.md CHANGELOG
%license COPYRIGHT
%{_libdir}/%{name}.so.*

%files devel
%{_libdir}/%{name}.so
%{_includedir}/%{name}.h
%{_libdir}/pkgconfig/imagequant.pc

%changelog
* Sun Jan 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.18:
  - added more perceptually-weighed color selection
  - dropped problematic omp_set_nested()
  - fixed a rare memory leak
* Mon Aug  8 2022 Dirk Müller <dmueller@suse.com>
- disable sse on non-x86 architectures
* Sat Nov 27 2021 Dirk Müller <dmueller@suse.com>
- update to 2.17.0:
  * Do not build as unversioned DSO
  * use float as in SSE
  * Initialize rows using heap to handle large images
  * Free rows after remapping
  * Disable SSE on arm64
* Sun Jun  6 2021 Dirk Müller <dmueller@suse.com>
- update to 2.15.1:
  - speed and quality improvements
* Sat May  8 2021 Dirk Müller <dmueller@suse.com>
- update to 2.14.1:
  * improved Rust API
  * quality improvements for remapping overlays over a background
* Wed Dec 23 2020 Dirk Müller <dmueller@suse.com>
- update to 2.13.1:
  * Support OpenMP in clang
  * speed improvements
* Sat Aug 15 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.12.6:
  * Use size_t for malloc_sizes
- remove gcc9-Update-const-var-openmp-const-var-handling.patch (upstream)
* Tue May 14 2019 Martin Liška <mliska@suse.cz>
- Add gcc9-Update-const-var-openmp-const-var-handling.patch in order
  to handle boo#1134979.
* Fri Feb 15 2019 munix9@googlemail.com
- update to version 2.12.2
  * new liq_histogram_add_fixed_color()
  * faster for large/complex images
* Wed Feb 13 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
* Thu Nov 16 2017 dimstar@opensuse.org
- Initial package, version 2.11.3 (library got split out from
  pngquant).
